==> haskell-aeson-casing-0.2.0.0-134-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-casing.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson-casing
version:              0.2.0.0
visibility:           public
id:                   aeson-casing-0.2.0.0-7N3bafXi72n3rmB66OB5Uq
key:                  aeson-casing-0.2.0.0-7N3bafXi72n3rmB66OB5Uq
license:              MIT
maintainer:           andrewrademacher@gmail.com
author:               Andrew Rademacher
synopsis:
    Tools to change the formatting of field names in Aeson
    instances.

description:
    Tools to change the formatting of field names in Aeson
    instances. This includes CamelCasing, Pascal Casing and
    Snake Casing.

category:             Data
abi:                  c9faf70f252c8042d7ead482036f9f55
exposed:              True
exposed-modules:      Data.Aeson.Casing Data.Aeson.Casing.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/aeson-casing-0.2.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/aeson-casing-0.2.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/aeson-casing-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-casing
hs-libraries:         HSaeson-casing-0.2.0.0-7N3bafXi72n3rmB66OB5Uq
depends:              aeson-2.1.2.1-KaceSWeAWkBK9urIr7RMHq base-4.17.2.1
haddock-interfaces:
    /usr/share/doc/haskell-aeson-casing/html/aeson-casing.haddock

haddock-html:         /usr/share/doc/haskell-aeson-casing/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-casing-0.2.0.0-135-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-casing.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson-casing
version:              0.2.0.0
visibility:           public
id:                   aeson-casing-0.2.0.0-17QtDOHomwp1CxUCjoP4O
key:                  aeson-casing-0.2.0.0-17QtDOHomwp1CxUCjoP4O
license:              MIT
maintainer:           andrewrademacher@gmail.com
author:               Andrew Rademacher
synopsis:
    Tools to change the formatting of field names in Aeson
    instances.

description:
    Tools to change the formatting of field names in Aeson
    instances. This includes CamelCasing, Pascal Casing and
    Snake Casing.

category:             Data
abi:                  bd71bfc6555e23659e950811b02c0a14
exposed:              True
exposed-modules:      Data.Aeson.Casing Data.Aeson.Casing.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/aeson-casing-0.2.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/aeson-casing-0.2.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/aeson-casing-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-casing
hs-libraries:         HSaeson-casing-0.2.0.0-17QtDOHomwp1CxUCjoP4O
depends:              aeson-2.1.2.1-JtwfP0wSn8NCfmI6cbJvU2 base-4.17.2.1
haddock-interfaces:
    /usr/share/doc/haskell-aeson-casing/html/aeson-casing.haddock

haddock-html:         /usr/share/doc/haskell-aeson-casing/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
